@@ -11,8 +11,4 @@ class ResponseWithBinary(Response):
     isLocal = os.environ.get('STAGE', 'dev') == 'dev'
     def to_dict(self, binary_types=None) -> dict:
         response = super().to_dict(binary_types=binary_types)
-        if self.isLocal:
-            response['isBase64Encoded'] = False
-        elif self.isBase64Encoded:
-            response['isBase64Encoded'] = True
         return response
\ No newline at end of file
